<h1 align="center">
	<img
		width="350"
		alt="GemPyp"
		src="https://gempyp.gemecosystem.com/static/media/Gempyp.e73184c67dca4df150fa37048866ecb6.svg">
</h1>

<h3 align="center">
	<div><h2>GemPyP</h2></div>
    An out of the box Python Automation Framework
</h3>

<p align="center">
	<strong>
		<a href="https://gempyp.gemecosystem.com/">Website</a>
		•
		 <a href="##">Docs</a>
		•
		 <a href="https://github.com/Gemini-Solutions/gempyp/">Repo</a>
	</strong>
</p>

<p align="center">
<img src="https://img.shields.io/badge/python-3.6-blue"/>
<img src="https://img.shields.io/pypi/dw/gempyp">
<img src="https://img.shields.io/pypi/v/gempyp?color=red&label=version&logo=gempyp">
<img src="https://img.shields.io/pypi/implementation/gempyp">

</p>

## Table of contents[![]()](#table-of-contents)

1. [Overview](#overview)
2. [Installation](#installation)
3. [Requirements](#requirements)
4. [Features](#features)
5. [Usage](#usage)
6. [Documentations](#docs)
7. [Contributors](#contributors)
8. [More](#more)
9. [Credits](#credits)

## Overview[![]()](#overview)

GemPyP is a testing and reporting framework that allows automatic execution of testcases along with generation of the report, that enables effortless analysis and monitoring of the set.

The setting and configurations, including the testcases are passed as a config file to the framework, then GemPyP handles the environments, execution, reporting, storing data and miscellaneous.

It allows-

- Email integration
- Parallel execution of testcases
- Customization of test Suite reports
- Platform independence (Supports Linux, Windows and MacOS)

## Installation[![]()](#installation)

For installation make sure require version of python and pip is installed in the system.

```powershell
$ pip install gempyp
```

## Requirements[![]()](#requirements)

### Python version 3.6 or above

### Required Libraries

- certifi==2022.6.15
- cffi==1.15.0
- charset-normalizer==2.0.12
- coloredlogs==15.0.1
- cryptography==37.0.2
- humanfriendly==10.0
- idna==3.3
- lxml==4.9.0
- ntlm-auth==1.5.0
- numpy==1.22.4
- pandas==1.4.2
- pycparser==2.21
- pyreadline3==3.4.1
- python-dateutil==2.8.2
- pytz==2022.1
- requests==2.28.0
- requests-ntlm==1.1.0
- six==1.16.0
- urllib3==1.26.9

### These libraries will get downloaded automatically with the package.

## Features[![]()](#features)

1. Easy to use.
2. Cross Platform.
3. Multiple modes of execution.
4. Static Report generated after execution.
5. Saves Time

## Usage[![]()](#usage)

### Can be used in API Automation and testing python testcases.

## Documentations[![]()](#docs)

The official documentation is hosted on Read the Docs: https://gempyp.readthedocs.io/en/latest/

## Contributors[![]()](#contributors)

We welcome and recognize all contributions. You can see a list of current contributors in the [contributors tab](https://github.com/Gemini-Solutions/gempyp/).

## More[![]()](#more)

For more information visit https://gempyp.gemecosystem.com/ and https://gemecosystem.com/

### Credits[![]()](#credits)

- TODO
